@@ -17,8 +17,26 @@ except MissingBackendError:
     bcrypt_available = False
 
 
+def test_prefix():
+    db = SQLAlchemy('sqlite:///test.db')
+    auth = authcode.Auth(SECRET_KEY, db=db, roles=True, prefix='foobar')
+    assert auth.User
+    assert auth.Role
+    db.create_all()
+    db.session.add(auth.User(login=u'MeH', password='foobar'))
+    db.session.commit()
+
+    assert auth.users_model_name == 'FoobarUser'
+    assert auth.roles_model_name == 'FoobarRole'
+    assert auth.views_prefix == 'foobar_'
+    assert auth.url_sign_in == '/foobar/sign-in/'
+    assert auth.url_sign_out == '/foobar/sign-out/'
+    assert auth.url_reset_password == '/foobar/reset-password/'
+    assert auth.url_change_password == '/foobar/change-password/'
+
+
 def test_automatic_case_insensitiveness():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db)
     User = auth.User
     db.create_all()
@@ -31,7 +49,7 @@ def test_automatic_case_insensitiveness():
 
 
 def test_disabled_case_insensitiveness():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db, case_insensitive=False)
     User = auth.User
     db.create_all()
@@ -46,7 +64,7 @@ def test_disabled_case_insensitiveness():
 
 
 def test_automatic_password_hashing():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db, hash='pbkdf2_sha512', rounds=10)
 
     User = auth.User
@@ -113,7 +131,7 @@ def test_legacy_reader():
 
 
 def test_sql_injection():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db, roles=True)
     User = auth.User
     db.create_all()
@@ -133,7 +151,7 @@ def test_sql_injection():
 
 
 def test_authenticate_with_password():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -161,7 +179,7 @@ def test_authenticate_with_password():
 
 
 def test_user_has_none_password():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -190,7 +208,7 @@ def test_user_has_none_password():
 
 
 def test_user_has_empty_password():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db, password_minlen=0)
 
     User = auth.User
@@ -222,7 +240,7 @@ def test_user_has_empty_password():
 
 
 def test_update_on_authenticate():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db, hash='pbkdf2_sha512',
                          update_hash=True)
     User = auth.User
@@ -247,7 +265,7 @@ def test_update_on_authenticate():
 
 
 def test_disable_update_on_authenticate():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db, hash='pbkdf2_sha512',
                          update_hash=False)
     User = auth.User
@@ -270,7 +288,7 @@ def test_disable_update_on_authenticate():
 
 def test_get_token():
     from time import time, sleep
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -293,7 +311,7 @@ def test_get_token():
 
 def test_authenticate_with_token():
     from time import time
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db, token_life=3 * 60)
 
     User = auth.User
@@ -326,7 +344,7 @@ def test_authenticate_with_token():
 
 
 def test_get_uhmac():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -341,7 +359,7 @@ def test_get_uhmac():
 
 
 def test_login_logout():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -360,7 +378,7 @@ def test_login_logout():
 
 
 def test_login_repeated_logout():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -382,7 +400,7 @@ def test_login_repeated_logout():
 
 
 def test_clear_session_on_logout():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -407,7 +425,7 @@ def test_clear_session_on_logout():
 
 
 def test_dont_clear_session_on_logout():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db, clear_session_on_logout=False)
 
     User = auth.User
@@ -432,7 +450,7 @@ def test_dont_clear_session_on_logout():
 
 
 def test_get_user():
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -482,7 +500,7 @@ def test_replace_hash_password_method():
                 return False
             return self.hash_password(secret) == hashed
 
-    db = SQLAlchemy()
+    db = SQLAlchemy('sqlite://')
     auth = CustomAuth(SECRET_KEY, db=db)
     User = auth.User
     db.create_all()
