@@ -9,8 +9,12 @@ from helpers import SECRET_KEY
 
 def test_user_model():
     db = SQLAlchemy()
-    auth = authcode.Auth(SECRET_KEY, db=db)
+    auth = authcode.Auth(SECRET_KEY, db=db, roles=True)
+    assert auth.users_model_name == 'User'
+    assert auth.roles_model_name == 'Role'
+
     User = auth.User
+    db.drop_all()
     db.create_all()
     user = User(login=u'meh', password='foobar')
     db.session.add(user)
@@ -27,6 +31,7 @@ def test_backwards_compatibility():
     db = SQLAlchemy()
     auth = authcode.Auth(SECRET_KEY, db=db)
     User = auth.User
+    db.drop_all()
     db.create_all()
     user = User(login=u'meh', password='foobar')
     db.session.add(user)
@@ -41,6 +46,7 @@ def test_user_model_methods():
     db = SQLAlchemy()
     auth = authcode.Auth(SECRET_KEY, db=db)
     User = auth.User
+    db.drop_all()
     db.create_all()
     user = User(login=u'meh', password='foobar')
     db.session.add(user)
@@ -63,6 +69,7 @@ def test_set_raw_password():
     db = SQLAlchemy()
     auth = authcode.Auth(SECRET_KEY, db=db, roles=True)
     User = auth.User
+    db.drop_all()
     db.create_all()
     user = User(login=u'meh', password='foobar')
     db.session.add(user)
@@ -77,6 +84,7 @@ def test_role_model():
     db = SQLAlchemy()
     auth = authcode.Auth(SECRET_KEY, db=db, roles=True)
     Role = auth.Role
+    db.drop_all()
     db.create_all()
     role = Role(name=u'admin')
     db.session.add(role)
@@ -90,6 +98,7 @@ def test_role_model_methods():
     db = SQLAlchemy()
     auth = authcode.Auth(SECRET_KEY, db=db, roles=True)
     Role = auth.Role
+    db.drop_all()
     db.create_all()
     role = Role(name=u'admin')
     db.session.add(role)
@@ -117,6 +126,7 @@ def test_add_role():
     auth = authcode.Auth(SECRET_KEY, db=db, roles=True)
     User = auth.User
     Role = auth.Role
+    db.drop_all()
     db.create_all()
     user = User(login=u'meh', password='foobar')
     db.session.add(user)
@@ -157,6 +167,7 @@ def test_remove_role():
     auth = authcode.Auth(SECRET_KEY, db=db, roles=True)
     User = auth.User
     Role = auth.Role
+    db.drop_all()
     db.create_all()
     user = User(login=u'meh', password='foobar')
     db.session.add(user)
@@ -206,6 +217,7 @@ def test_models_mixins():
     User = auth.User
     Role = auth.Role
 
+    db.drop_all()
     db.create_all()
     user = User(login=u'meh', password='foobar', email=u'text@example.com')
     db.session.add(user)
